@@ -32,6 +32,7 @@ def _read_schema():
 
 
 def create_custom_init(editor: PatcherEditor, configuration: dict):
+    cosmetic_options: dict = configuration["cosmetic_patches"]["lua"]["custom_init"]
     inventory: dict[str, int] = configuration["starting_items"]
     starting_location: dict = configuration["starting_location"]
     starting_text: list[list[str]] = configuration.get("starting_text", [])
@@ -88,7 +89,8 @@ def create_custom_init(editor: PatcherEditor, configuration: dict):
         "linear_damage_runs": configuration.get("linear_damage_runs"),
         "linear_dps": configuration.get("linear_dps"),
         "configuration_identifier": lua_util.wrap_string(configuration_identifier),
-        "required_artifacts": configuration["objective"]["required_artifacts"]
+        "required_artifacts": configuration["objective"]["required_artifacts"],
+        "enable_death_counter": cosmetic_options["enable_death_counter"]
     }
 
     replacement.update(configuration.get("game_patches", {}))
@@ -109,10 +111,10 @@ def patch_pickups(editor: PatcherEditor, lua_scripts: LuaEditor, pickups_config:
             LOG.warning(e)
 
 
-def patch_doors(editor: PatcherEditor, doors_config: list[dict], show_shields: bool = False):
-    door_editor = DoorPatcher(editor, show_shields)
+def patch_doors(editor: PatcherEditor, doors_config: list[dict]):
+    door_patcher = DoorPatcher(editor)
     for door in doors_config:
-        door_editor.patch_door(door["actor"], door["door_type"])
+        door_patcher.patch_door(door["actor"], door["door_type"])
 
 
 def patch_spawn_points(editor: PatcherEditor, spawn_config: list[dict]):
@@ -190,7 +192,7 @@ def patch_extracted(input_path: Path, output_path: Path, configuration: dict):
         patch_hints(editor, configuration["hints"])
 
     # Doors
-    patch_doors(editor, configuration["door_patches"], configuration["show_shields_on_minimap"])
+    patch_doors(editor, configuration["door_patches"])
 
     # custom spawn points
     patch_spawn_points(editor, configuration["new_spawn_points"])
